# Force Draw on 32x32 LED Matrix
import board
import displayio
import framebufferio
import rgbmatrix
import time
from adafruit_apds9960.apds9960 import APDS9960
import busio

#Set up APDS-9960
i2c = busio.I2C(board.GP17, board.GP16)

multisensor = APDS9960(i2c)
multisensor.enable_proximity = True
multisensor.enable_gesture = True

# Initialize the matrix
displayio.release_displays()
matrix = rgbmatrix.RGBMatrix(
    width=32, height=32,
    bit_depth=6,
    rgb_pins=[board.GP0, board.GP1, board.GP2, board.GP3, board.GP4, board.GP5],
    addr_pins=[board.GP6, board.GP7, board.GP8, board.GP9],
    clock_pin=board.GP10,
    latch_pin=board.GP12,
    output_enable_pin=board.GP13
)
display = framebufferio.FramebufferDisplay(matrix)

# Create a bitmap
bitmap = displayio.Bitmap(32, 32, 8)
palette = displayio.Palette(8)

# Define basic colors
palette[0] = 0x000000  # Black (Off)
palette[1] = 0xFFFFFF  # White (Past Pixels)
palette[2] = 0xFF0000  # Red (Current Cursor)

# Create the display elements
tile_grid = displayio.TileGrid(bitmap, pixel_shader=palette)
group = displayio.Group()
group.append(tile_grid)
display.root_group = group

# Set brightness
display.brightness = 0.75

# First make everything black
for y in range(32):
    for x in range(32):
        bitmap[x, y] = 0  # Black

# Initializing variables
x, y = 16, 16  # Start in the middle
prev_x, prev_y = None, None  # Track last position
cancel_count = 0

# Keep the middle pixel red initially
bitmap[x, y] = 2  # Red (Cursor)

while True:
    # Get gesture input
    gesture = multisensor.gesture()

    # Store the previous position
    prev_x, prev_y = x, y

    if gesture is not None:
        if gesture == 4:  # Left
            y += 1
            print("Left")
            print(y)
        elif gesture == 3:  # Right
            y -= 1
            print("Right")
            print(y)
        elif gesture == 2:  # Up
            x -= 1
            print("Up")
            print(x)
        elif gesture == 1:  # Down
            x += 1
            print("Down")
            print(x)

        # Increment cancel count if at an edge
        if x in (-1, 32) or y in (-1, 32):
            cancel_count += 1
            print(f"cancel = {cancel_count}")
        elif x in (1, 30) or y in (1, 30):
            cancel_count = 0

    # Keep x, y in valid range (0-31)
    x = max(0, min(31, x))
    y = max(0, min(31, y))

    # Set the previous pixel to white (trail)
    if prev_x is not None and prev_y is not None:
        bitmap[prev_x, prev_y] = 1  # White

    # Reset if out of bounds too many times
    if cancel_count >= 3:
        # If the last out-of-bounds pixel was white, clear it
        if prev_x is not None and prev_y is not None and bitmap[prev_x, prev_y] == 1:
            bitmap[prev_x, prev_y] = 0  # Clear white trail

        # Clear the entire screen
        for py in range(32):
            for px in range(32):
                bitmap[px, py] = 0  # Black

        # Reset cursor position to center
        x, y = 16, 16
        cancel_count = 0

    # Set the current pixel to red (cursor)
    bitmap[x, y] = 2  # Red (Current)

    time.sleep(0.1)